@@ -178,9 +178,9 @@ sub to_perl {
     $Data::Dumper::Indent = 1;
     $Data::Dumper::Sortkeys = 1;
     my $perl = Data::Dumper::Dumper($self->tree);
-    $perl =~ s/\?\^:/?-xism:/g;
+    $perl =~ s/\?\^u?:/?-xism:/g; # the "u" is perl 5.14-18 equiv of /u
     $perl =~ s!(\.rgx.*?qr/)\(\?-xism:(.*)\)(?=/)!$1$2!g;
-    $perl =~ s!/u$!/!gm; # new perls put /u, old perls don't understand
+    $perl =~ s!/u$!/!gm; # perl 5.20+ put /u, older perls don't understand
     die "to_perl failed with non compatible regex in:\n$perl"
         if $perl =~ /\?\^/;
     return $perl;
